#pragma rtGlobals=3		// Use modern global access method and strict wave access.

		
	*********************************************************
	
	Function Site_2_Site_Image_Stretch()
		SetDataFolder root:
			Variable/G G_Resolution
			Variable Resolution = G_Resolution
			String/G G_BaseSite, G_StretchSite
			String BaseSite = G_BaseSite, StretchSite = G_StretchSite; 
			Prompt BaseSite "BaseSite"
			Prompt StretchSite "StretchSite"
			Prompt Resolution "Depth Resolution of Stretched Image ( m ) "
			DoPrompt "Site_2_Site_Image_Stretch" BaseSite, StretchSite, Resolution; AbortOnValue V_Flag, 0
			G_BaseSite = BaseSite; G_StretchSite = StretchSite;	G_Resolution = Resolution
			Site_2_Site_Image_Stretch_F( BaseSite, StretchSite, Resolution )		
			Print "Site_2_Site_Image_Stretch_F( \"" + BaseSite +"\", \"" + StretchSite +  "\", ", Resolution, " )"
	EndMacro
	
	*********************************************************
	
	Function Site_2_Site_Image_Stretch_F( BaseSite, StretchSite, Resolution )
		Variable Resolution
		String BaseSite, StretchSite
		Variable i=0
		SetDataFolder root:
			PauseUpdate
			Variable X1, X2
			WAVE BaseTies, StretchTies, TieType
			CheckTiesForDupes( BaseTies, StretchTies )
			WAVE Stretched_Splice = $StretchSite + "_2_" + BaseSite + "_Str" // This wave is initially formed using the SetUp function
			Sort BaseTies StretchTies, BaseTies
		SetDataFolder $"root:Xtras"
			WAVE Ones, Numbers
		SetDataFolder $"root:" + BaseSite + "_" + StretchSite + "_Results" 
			Duplicate/O BaseTies $BaseSite + "_2_" + StretchSite + "_Ties"
			Duplicate/O StretchTies $StretchSite + "_2_" + BaseSite + "_Ties"
			Duplicate/O TieType $StretchSite + "_2_" + BaseSite + "_TieType"
		SetDataFolder root: 	
			Duplicate/O BaseTies Ones, Numbers
			Ones = .5
			Numbers = x
			WAVE Image = $StretchSite + "_Splice"
			SetScale/I y 0,1,"", Image
			WaveStats/Q StretchTies
			ImageInterpolate/S = { V_Min, Resolution, V_Max, 0, .01, 1 }/DEST = StrImg Bilinear Image //Make a copy of the original image to be stretched with "regular" scaling
			WaveStats/Q BaseTies
				// Make a wave to hold the stretched sections that is the same length as the base site section that has been tied to the stretch image
			Make/O/N = ( ( V_Max - V_Min )/ Resolution, 101, 3 ) $StretchSite + "_2_" + BaseSite + "_Str"
			WAVE Stretched_Splice = $StretchSite + "_2_" + BaseSite + "_Str"
			InsertPoints 0, 1, Stretched_Splice // Insert a point to avoid any scaling problem at the last stretched section
			ReDimension/B/U Stretched_Splice
			SetScale/P x V_Min, Resolution, "", Stretched_Splice
			SetScale/P y 0, .01, "", Stretched_Splice 
			Stretched_Splice = NaN
			Variable StrTop, StrBottom, BsTop, BsBottom
			For( i = 0; i < NumPnts( BaseTies ) - 1; i += 1 ) 
				StrTop = StretchTies[ i ]; StrBottom = StretchTies[ i + 1 ]
				BsTop = BaseTies[ i ]; BsBottom = BaseTies[ i + 1 ]
				If( Round( StrTop * 100 ) == Round( StrBottom * 100 ) )		// This bit places NaN gaps in the stretched image whan hiatuses are present in the stretch site. It checks tie points to the nearest .01 for equality
					Make/O/N = ( 2, 101, 3 ) Temp
					Temp = NaN		
				Else
					Duplicate/O/R=( StrTop, StrBottom ) StrImg  Temp // Cut Section Between Stretch Site depths
				EndIf	
				If( Round( BsTop * 100 ) == Round( BsBottom * 100 ) ) // Looks for errors in the Base Ties - repeated depths
					ABORT "Base Ties " + Num2Str( i ) + " and " + Num2Str( i + 1 ) + " are the same. There is no interval to accept the squeezed section of the Stretch image."
				EndIf
				SetScale/I x BsTop, BsBottom, "", Temp // Rescale cut section to corresponding Base Site depths
				SetScale/I y 0, 1, "", Temp // Rescale y from 0 to 1
				ImageInterpolate/S = { BsTop, Resolution, BsBottom, 0, .01, 1 }/DEST = Temp2 Bilinear Temp // Make a new cut section at the same resolution as the stretched image
				ReDimension/B/U Temp2
				X1 = X2Pnt( Stretched_Splice, LeftX( Temp2 ) )
				X2 = X2Pnt( Stretched_Splice, ( RightX( Temp2 ) - Resolution ) )
				If( X2 >= DimSize( Stretched_Splice, 0 ) ) // Takes care of some rounding problems that may cause an error adding the final section
					X2 = DimSize( Stretched_Splice, 0 ) - 1
				EndIf
				Stretched_Splice[ X1, X2 ][ ][ ] = Temp2[ p - X1 ][ q ][ r ] // Adds the section to the stretched iamge
			EndFor
			KillWaves StrImg
			KillWaves Temp, Temp2
	End

	
	
	
	
	
	
// This is the old stretch function using concatenate.	
	
//	Function Site_2_Site_Image_Stretch_F( BaseSite, StretchSite )
		String BaseSite, StretchSite
		Variable i=0
		SetDataFolder root:
			PauseUpdate
			WAVE BaseTies, StretchTies
			CheckTiesForDupes( BaseTies, StretchTies )
			WAVE Stretched_Splice = $StretchSite + "_2_" + BaseSite + "_Str" // This wave is initially formed using the SetUp function
			Sort BaseTies StretchTies, BaseTies
		SetDataFolder $"root:Xtras"
			WAVE Ones, Numbers
		SetDataFolder $"root:" + BaseSite + "_" + StretchSite + "_Results" 
			Duplicate/O BaseTies $BaseSite + "_2_" + StretchSite + "_Ties"
			Duplicate/O StretchTies $StretchSite + "_2_" + BaseSite + "_Ties"
		SetDataFolder root: 	
			Duplicate/O BaseTies Ones, Numbers
			Ones = .5
			Numbers = x
			If( StrLen( CsrWave( B ) ) == 0 )
				ABORT "You need to put the cursors on the images before stretching so the function knows which core to stretch.\r\rCursor A on the Base Image, Cursor B on the image to be stretched."
			Endif
			WAVE StrImg =  CsrWaveRef( B )
			Redimension/N=( 0, 101, 3 ) Stretched_Splice
			SetScale/I y 0, 1, "", Stretched_Splice
			SetScale/P x 0, .002, "", Stretched_Splice // Sets the interpolated image depth resolution to 2 mm
			Variable StrTop, StrBottom, BsTop, BsBottom
			For( i = 0; i < NumPnts( BaseTies ) - 1; i += 1 ) 
				StrTop = StretchTies[ i ]; StrBottom = StretchTies[ i + 1 ]
				BsTop = BaseTies[ i ]; BsBottom = BaseTies[ i + 1 ]
				If( StrTop == StrBottom )		// This bit places NaN gaps in the stretched image whan hiatuses are present
					Make/O/N = ( 2, DimSize( StrImg, 1 ), 3 ) Temp
					Temp = NaN		
				Else
					Duplicate/O/R=( StrTop, StrBottom ) StrImg  Temp 
				EndIf	
				SetScale/I x BsTop, BsBottom, "", Temp 
				SetScale/I y 0, 1, "", Temp 
				ImageInterpolate/S = { BsTop, .002, BsBottom, 0, .01, 1 }/DEST = Temp2 Bilinear Temp
				ReDimension/B/U Temp2
				Concatenate/NP = 0 "Temp2;" , Stretched_Splice
			EndFor
			KillWaves Temp, Temp2
	End

