#pragma rtGlobals=3		// Use modern global access method.
	
	// Changed 17/6/2017 to add splice_format to the SpliceDataCheck routine
	// 29/6/2017 added CheckImages4Splicing - a subroutine that makes sure that the splice interval is within the core image.
		
	Function Splice_Images(  )
		SetDataFolder root:
			String/G G_Site
			Variable/G G_Resolution
			Variable Resolution = G_Resolution
			String Site = G_Site, Splice_Folder, Splice_Format = "Splice_Intervals"
			String Hole, S2, Top = Site+"_Top" ,Bottom = Site + "_Bottom"
			Variable i = 0, Splice_Length, Core, Splice_Bottom, Splice_Top, SecPixLen
			Prompt Site, "Site"
			Prompt Splice_Format,  "Use Splice Ties or Splice Intervals Format?",  popup,  "Splice_Intervals;Splice_Ties"
			Prompt Resolution, "Depth Resolution ( m ):"
			DoPrompt "Splice_Images", Site, Splice_Format, Resolution; AbortOnValue V_Flag, 0
			G_Site = Site; G_Resolution = Resolution
			PauseUpdate;
	
			If( SpliceDataCheck( Site, Splice_Format ) ) // This is a separate function to check the splice tables, both intervals and ties.
				Abort
			Endif
			String AbortMsg = "There are splice intervals that fall outside the depth range of the appropriate core image.\r\r"
			AbortMsg = AbortMsg + "See the History scroll for listing of problems.\r "

			If( CheckImages4Splicing( Site, Splice_Format ) )
				Print "The errors above sometimes happen if you forgot to run CSF_2_CCSF\r\t\tto set the core images to their offset depths.\r"
				Print "Another possible problem occurs when APPENDING cores.\r"
				Print "Try adding 1 cm to the top CCSF of the splice interval and/or subtracting 1 cm from the bottom CCSF."
				ABORT AbortMsg
			EndIf

			If( StringMatch( Splice_Format, "Splice_Intervals" )  ) // This is for the Splice Interval form of the splice data
				SetDataFolder $Site+"_Splice_Intervals"
					WAVE/T Hole_Top
					WAVE Core_Top, CCSF_Top, CCSF_Bottom
					Hole = Hole_Top[ i ]
					Core = Core_Top[ i ]
					If( Core < 10 )
						Wave CoreImage = $"root:" + Site + Hole + "_S2:S2_" + Site + Hole + "_0" + num2str( Splice_Interval_Core( Site, i ) )
					Else
						WAVE CoreImage = $"root:" + Site + Hole + "_S2:S2_" + Site + Hole + "_" + num2str( Splice_Interval_Core( Site, i ) )
					EndIf
			Else  				
				SetDataFolder $Site+"_Splice_Ties"  // This is for the Splice Ties form of the splice data
					WAVE/T Hole_Bottom
					WAVE Core_Bottom, CCSF_Top, CCSF_Bottom
					Hole = Hole_Bottom[ i ]
					Core = Core_Bottom[ i ]
					If( Splice_Tie_Core( Site, i ) < 10 )
						WAVE CoreImage = $"root:" + Site + Hole + "_S2:S2_" + Site + Hole + "_0" + num2str( Splice_Tie_Core( Site, i ) )
					Else
						WAVE CoreImage = $"root:" + Site + Hole + "_S2:S2_" + Site + Hole + "_" + num2str( Splice_Tie_Core( Site, i ) )
					EndIf
			EndIf	
		SetDataFolder root:
			CheckImageScaling()
			Wavestats/Q CCSF_Bottom // Get the length of the spliced image from the depth of the bottom splice interval
			Splice_Length = ( V_Max / Resolution ) + 2 // Calculate the length in pixels of the spliced image			
			Make/O/B/U/N = ( Splice_Length, 101, 3  ) $Site + "_Splice" // Create the Spliced Image with the right dimensions
			WAVE SplicedImage = $Site + "_Splice"
			SetScale/I y 0, 1,"", SplicedImage
			SetScale/P x, 0, Resolution, SplicedImage // Scale the spliced image
			SplicedImage = NaN
		
	// This section sets up the first piece of the splice 			
			If( StringMatch( Splice_Format, "Splice_Intervals" )  )
				Splice_Bottom = CCSF_Bottom[ 0 ]
				Splice_Top = CCSF_Top[ 0 ]
			Else
				Splice_Bottom = Splice_Tie_Bottom( Site, 0 )
				Splice_Top = Splice_Tie_Top( Site, 0 )	
			EndIf
			Duplicate/O/R = ( Splice_Top, Splice_Bottom ) CoreImage Temp
			SetScale/P y 0,0.01,"", Temp
			SetScale x Splice_Top, Splice_Bottom,"", Temp
			EXECUTE Site + "_Splice( " + Num2Str( LeftX( Temp ) ) + ", " + Num2Str( RightX( Temp ) ) + " )()() = Temp( x )( y )( z )"	
			Printf  "Working  on %s Line ", Splice_Format
			Variable Error = GetRTError( 1 )
	// This loop fills in the rest of the splice sections.			
			For( i = 0; i < V_Npnts; i += 1 )				
				If( StringMatch( Splice_Format, "Splice_Intervals" )  )  // This	 If is for splice intervals	
					Splice_Bottom = CCSF_Bottom[ i ]
					Splice_Top = CCSF_Top[ i ]
					Hole = Hole_Top[ i ]
					Core = Core_Top[ i ]

					If( Splice_Interval_Core( Site, i ) < 10 )
						WAVE/Z CoreImage = $"root:" + Site + Hole + "_S2:S2_" + Site + Hole + "_0" + num2str( Splice_Interval_Core( Site, i ) )
					Else
						WAVE/Z CoreImage = $"root:" + Site + Hole + "_S2:S2_" + Site + Hole + "_" + num2str( Splice_Interval_Core( Site, i ) )
					EndIf			
				Else // this is for splice ties
					Splice_Bottom = Splice_Tie_Bottom( Site, i )
					Splice_Top = Splice_Tie_Top( Site, i )
					Core = Splice_Tie_Core( Site, i )	
					Hole = Splice_Tie_Hole( Site, i )
					If( Splice_Tie_Core( Site, i ) < 10 )
						WAVE/Z CoreImage = $"root:" + Site + Hole + "_S2:S2_" + Site + Hole + "_0" + num2str( Splice_Tie_Core( Site, i ) )
					Else
						WAVE/Z CoreImage = $"root:" + Site + Hole + "_S2:S2_" + Site + Hole + "_" + num2str( Splice_Tie_Core( Site, i ) )
					EndIf
				EndIf
				If( StrLen( NameOfWave( CoreImage ) ) > 0 ) // This checks for the case where there are appended cores to the splice that have no image, usuallly when all that was recovered was a core catcher
					SecPixLen = ( ( Splice_Bottom - Splice_Top ) / Resolution ) + 2
					Duplicate/O/R=( Splice_Top, Splice_Bottom ) CoreImage Temp
					EXECUTE Site + "_Splice( " + Num2Str( LeftX( Temp ) ) + ", " + Num2Str( RightX( Temp ) ) + " )()() = Temp( x )( y )( z )"
					Error = GetRTError( 1 )
		
					If( !mod( i, 10 ) ) // prints a message so the user knows the function is running since this can take a while on slower machines
						Printf  "  %d", i
					EndIf
				EndIf
			EndFor
			SetScale/I y 0, 1,"", SplicedImage
			Printf  "  %d   Finished!\r", i
			KillWaves/z Temp, M_InterpolatedImage
	EndMacro
	
	****************************************************************
		
